@@ -1,5 +1,5 @@
 # 2022.3.20,  coding=utf-8, 2022.1.11 uvicorn dims-fastapi:app --host 0.0.0.0 --port 7072 --reload
-import collections,math, marisa_trie, re,itertools,logging,fire,base64
+import collections,math, marisa_trie, re,itertools,fire,base64
 import numpy as np
 import en
 from dic.word_idf	import word_idf
@@ -65,9 +65,6 @@ def get_dims(ess):
 			map[name]= 0
 	return map
 
-import uvicorn,fastapi
-app	= fastapi.FastAPI() 
-
 def docs_to_dims(snts:list, docs:list):
 	''' updated 2022.3.20 '''
 	ess = {'snts': snts, 'docs': docs, 'tc': sum([len(d) for d in docs]), 'snt_num': len(docs), 
@@ -79,31 +76,26 @@ def docs_to_dims(snts:list, docs:list):
 	dims.update({"tc": ess['tc'], "snt_num": ess['snt_num'], "word_num": ess['word_num'], "word_type": ess['word_type']})
 	return dims
 
+def uvirun(port): 
+	''' python -m dsk.mkf uvirun 17095 '''
+	import fastapi,uvicorn
+	app		= fastapi.FastAPI()
 
-@app.post('/dims/snts')
-def snts_to_dims(snts:list=["She has ready.","I believe I can do it."], use_cache:bool=True):
-	''' updated 2022.3.20 '''
-	docs = [spacy.getdoc(snt, use_cache) for snt in snts]
-	return docs_to_dims(snts, docs) 
+	@app.get('/')
+	def home(): return fastapi.responses.HTMLResponse(content=f"<h2>snts_dims</h2> <a href='/docs'> docs </a> | <a href='/redoc'> redoc </a> <br> last update: 2022-1-12 <hr>")
 
-@app.get('/dims/essay')
-def essay_to_dims(essay:str="She has ready. I believe I can do it."): 	
-	''' updated 2022.3.20 '''
-	return snts_to_dims( spacy.snts(essay) )
+	@app.post('/dims/snts')
+	def snts_to_dims(snts:list=["She has ready.","I believe I can do it."], use_cache:bool=True):
+		''' updated 2022.3.20 '''
+		docs = [spacy.getdoc(snt, use_cache) for snt in snts]
+		return docs_to_dims(snts, docs) 
 
-@app.get('/')
-def home(): return fastapi.responses.HTMLResponse(content=f"<h2>snts_dims</h2> <a href='/docs'> docs </a> | <a href='/redoc'> redoc </a> <br> last update: 2022-1-12 <hr>")
+	@app.get('/dims/essay')
+	def essay_to_dims(essay:str="She has ready. I believe I can do it."): 	
+		''' updated 2022.3.20 '''
+		return snts_to_dims( spacy.snts(essay) )
 
-class util(object): 
-	def __init__(self): pass
-
-	def hello(self):  
-		''' snts-to-dims  '''
-		print (  snts_to_dims() )
-
-	def uvirun(self, port) : 
-		''' python -m en.dims uvirun 8000 '''
-		uvicorn.run(app, host='0.0.0.0', port=port)
+	uvicorn.run(app, host='0.0.0.0', port=port)
 
 if __name__ == "__main__":  
-	fire.Fire(util)
\ No newline at end of file
+	fire.Fire(uvirun)
\ No newline at end of file
