@@ -8,10 +8,10 @@ add = lambda *names: [fire.si.update({name: 1}) for name in names if  not '\t' i
 
 def walk(doc): 
 	add(f"#SNT") 
+	[add( f"{t.lemma_}:POS:{t.pos_}", f"{t.lemma_}:LEX:{t.text.lower()}", f"LEM:{t.lemma_}", f"LEX:{t.text.lower()}", f"{t.pos_}:{t.lemma_.lower()}"
+		, f"{t.tag_}:{t.lemma_.lower()}",f"{t.lemma_.lower()}:{t.pos_}:{t.tag_}:{t.text.lower()}",f"{t.lemma_.lower()}:{t.pos_}:{t.tag_}", f"{t.lemma_.lower()}:{t.pos_}") for t in doc if not t.pos_ in ('PROPN','X', 'PUNCT') and t.is_alpha ]
 	for t in doc:
-		if not t.pos_ in ('PROPN','X', 'PUNCT'): add( f"{t.lemma_}:POS:{t.pos_}")
-		add(f"{t.lemma_}:LEX:{t.text.lower()}", f"LEM:{t.lemma_}", f"LEX:{t.text}", f"{t.pos_}:{t.lemma_}", f"{t.tag_}:{t.lemma_}", "#LEX", f"#{t.pos_}", f"#{t.tag_}",f"#{t.dep_}",)
-		add(f"{t.lemma_}:{t.pos_}:{t.tag_}:{t.text.lower()}",f"{t.lemma_}:{t.pos_}:{t.tag_}", f"{t.lemma_}:{t.pos_}") # book:VERB:VBG
+		add( "#LEX", f"#{t.pos_}", f"#{t.tag_}",f"#{t.dep_}",) # book:VERB:VBG
 		if t.pos_ not in ("PROPN","PUNCT","SPACE"): 
 			add(f"{t.head.lemma_}:{t.head.pos_}:{t.dep_}:{t.pos_}:{t.lemma_}", f"{t.head.lemma_}:{t.head.pos_}:{t.dep_}")
 			if t.dep_ not in ('ROOT'): add(f"{t.lemma_}:{t.pos_}:~{t.dep_}:{t.head.pos_}:{t.head.lemma_}", f"{t.lemma_}:{t.pos_}:~{t.dep_}")
@@ -19,8 +19,6 @@ def walk(doc):
 		add(f"{sp.root.lemma_.lower()}:{sp.root.pos_}:np:{sp.text.lower()}", f"{sp.root.lemma_.lower()}:{sp.root.pos_}:np", f"#np",)
 
 	# [('pp', 'on the brink', 2, 5), ('ap', 'very happy', 9, 11)]
-	#for type, chunk, start, end in en.vp_matcher(doc): #[('vend', 'consider going', 1, 3) #consider:VERB:vtov:consider to go
-	#	add(f"{doc[start].lemma_}:{doc[start].pos_}:{type}:{chunk}", f"{doc[start].lemma_}:{doc[start].pos_}:{type}") if type.startswith("v") else add(f"{doc[end-1].lemma_}:{doc[end-1].pos_}:{type}:{chunk}", f"{doc[end-1].lemma_}:{doc[end-1].pos_}:{type}" ) 
 	for lem, pos, type, chunk in en.kp_matcher(doc): 
 		add(f"{lem}:{pos}:{type}:{chunk}", f"{lem}:{pos}:{type}", f"#{type}")
 
@@ -35,7 +33,7 @@ def walk(doc):
 			if doc[verbi].lemma_.isalpha() : 
 				add(f"{doc[verbi].lemma_}:{doc[verbi].pos_}:verbnet:{chunk}") #consider:VERB:verbnet:NP V S_ING
 
-def mysql(dbfile, host='127.0.0.1', port=3307):  
+def mysql(dbfile, host='127.0.0.1', port=3307, cutoff=0):  
 	''' clec.spacybs -> mysql:kpsi/clec,clec_snt , 2022.7.4 '''
 	import pymysql
 	print ("started index:", dbfile, flush=True)
@@ -50,36 +48,60 @@ def mysql(dbfile, host='127.0.0.1', port=3307):
 
 		for rowid, snt, doc in tqdm(Spacybs(dbfile).docs()) :
 			try:
-				cursor.execute(f"insert ignore into {name}_snt(sid, snt, kps) values(%s, %s, %s)", (rowid,snt, " ".join([ f"{t.lemma_}_{t.pos_}" for t in doc] + [ f"{t.lemma_}_{t.tag_}" for t in doc] + [ f"{t.head.lemma_}_{t.head.pos_}_{t.dep_}_{t.pos_}_{t.lemma_}" for t in doc if t.pos_ not in ('PRON','PUNCT') and t.dep_ in ('dobj','nsubj','advmod','acomp','amod','compound','xcomp','ccomp')]) ))
+				cursor.execute(f"insert ignore into {name}_snt(sid, snt, kps) values(%s, %s, %s)", (rowid,snt, " ".join([ f"{t.lemma_}_{t.pos_}" for t in doc  if t.pos_ not in ('PUNCT')] + [ f"{t.lemma_}_{t.tag_}" for t in doc  if t.pos_ not in ('PUNCT')] + [ f"{t.head.lemma_}_{t.head.pos_}_{t.dep_}_{t.pos_}_{t.lemma_}" for t in doc if t.pos_ not in ('PRON','PUNCT') and t.dep_ in ('dobj','nsubj','advmod','acomp','amod','compound','xcomp','ccomp','oprd')]) ))
 				walk(doc)
 			except Exception as e: 
 				print ("ex:", e, rowid, snt)
 				exc_type, exc_value, exc_traceback_obj = sys.exc_info()
 				traceback.print_tb(exc_traceback_obj)
 
-		cursor.executemany(f"insert ignore into {name}(s, i) values(%s, %s)",[(k,v) for k,v in fire.si.items()]) #cursor.executemany(f"INSERT INTO {name}(s,i) VALUES (%s, %s) ON DUPLICATE KEY UPDATE i = i + %s", [(k,v,v) for k,v in fire.si.items()] )
+		cursor.executemany(f"insert ignore into {name}(s, i) values(%s, %s)",[(k,v) for k,v in fire.si.items() if v > cutoff]) 
+		cursor.execute(f"DROP FUNCTION IF EXISTS {name}i")
+		cursor.execute(f'''CREATE FUNCTION {name}i(term varchar(64)) RETURNS INT
+ READS SQL DATA
+BEGIN
+	RETURN (SELECT i FROM {name} WHERE s = term limit 1);
+END''')
 		my_conn.commit()
 	print ("finished submitting:", dbfile, flush=True) 
 
-def tsv(dbfile):  
-	''' clec.spacybs -> clec.si.tsv, clec.snt.tsv '''
+def tsv(dbfile, cutoff=1):  
+	''' bnc.spacybs -> bnc.si.tsv, bnc.snt.tsv ,  commonly large file, so filtered with cutoff '''
 	print ("started index:", dbfile, flush=True)
 	name = dbfile.lower().split('.')[0]
 	fire.si = Counter()
 	with open (f"{name}.tsv.snt", "w", encoding='UTF-8') as fw:
-		for rowid, snt, doc in tqdm(Spacybs(dbfile).docs()) : #for rowid, snt, bs in tqdm(Spacybs(dbfile).items()) :
+		for rowid, snt, doc in Spacybs(dbfile).docs() : #for rowid, snt, bs in tqdm(Spacybs(dbfile).items()) :
 			try: #doc =  spacy.frombs(bs)
-				terms = " ".join([ f"{t.lemma_}_{t.pos_}" for t in doc] + [ f"{t.lemma_}_{t.tag_}" for t in doc] + [ f"{t.head.lemma_}_{t.head.pos_}_{t.dep_}_{t.pos_}_{t.lemma_}" for t in doc if t.pos_ not in ('PRON','PUNCT') and t.dep_ in ('dobj','nsubj','advmod','acomp','amod','compound','xcomp','ccomp')]) 
+				terms = " ".join([ f"{t.lemma_}_{t.pos_}" for t in doc] + [ f"{t.lemma_}_{t.tag_}" for t in doc] + [ f"{t.head.lemma_}_{t.head.pos_}_{t.dep_}_{t.pos_}_{t.lemma_}" for t in doc if t.pos_ not in ('PRON','PUNCT') and t.dep_ in ('dobj','nsubj','advmod','acomp','amod','compound','xcomp','ccomp','prep')]) 
 				fw.write(f"{rowid}\t{snt}\t{terms}\n")
 				walk(doc)
 			except Exception as e:
 				print ("ex:", e, rowid, snt)
 	with open (f"{name}.tsv.si", "w", encoding='UTF-8') as fw:
-		[ fw.write(f"{k}\t{v}\n") for k,v in fire.si.items()] 
+		[ fw.write(f"{k}\t{v}\n") for k,v in fire.si.items() if v > cutoff ] 
 	print ("finished submitting:", dbfile, flush=True) 
 
+def batch(names="qdu,gzjc,gaokao,clec,dic"):
+	''' batch model, --names qdu,gzjc,gaokao,clec,dic '''
+	[mysql(f"{name}.spacybs") for name in names.strip().split(',')]
+
+def trp(dbfile, cutoff=1):  
+	''' bnc.spacybs -> bnc.trp.tsv, commonly large file, so filtered with cutoff '''
+	print ("started index:", dbfile, flush=True)
+	name = dbfile.lower().split('.')[0]
+	fire.si = Counter()
+	for rowid, snt, doc in Spacybs(dbfile).docs() : 
+		try: 
+			[add(f"{t.head.lemma_}:{t.head.pos_}:{t.dep_}:{t.pos_}:{t.lemma_}") for t in doc if t.pos_ not in ("PROPN","PUNCT","SPACE") and t.is_alpha and t.head.is_alpha ]
+		except Exception as e:
+			print ("ex:", e, rowid, snt)
+	with open (f"{name}.trp.si", "w", encoding='UTF-8') as fw:
+		[ fw.write(f"{k}\t{v}\n") for k,v in fire.si.items() if v > cutoff ] 
+	print ("finished writing trp.si:", dbfile, flush=True) 
+	
 if __name__	== '__main__':
-	fire.Fire({"mysql":mysql, "tsv":tsv})
+	fire.Fire({"mysql":mysql, "tsv":tsv, "batch":batch, 'trp':trp })
 
 '''
 
