@@ -38,7 +38,7 @@ def getlog(logfile='daily.log'):
 	logger.addHandler(handler)
 	return logger
 
-def readline(infile, sepa=None):
+def readline(infile, sepa=None): #for line in fileinput.input(infile):
 	with open(infile, 'r', encoding='utf-8') as fp:
 		while True:
 			line = fp.readline()
