@@ -49,13 +49,36 @@ def doc_meta(text:str='She is happy.'):
 		print("ex:", e) 
 
 @app.post('/spacy/desc', tags=["spacy"])
-def doc_desc(dic:dict = {"Person=1":"第一人称","Person=3":"第三人称","Number=Sing":"单数", "AUX":"助动词", "VERB":"动词", "NOUN":"名词", "ADJ":"形容词", "ADV":"副词", "PRON":"代词","dobj":"宾语", 'nsubj':'主语','ROOT':"谓语", "acomp":"表语", "Tense=Pres":"现在时", "Tense=Past":"过去时"}
+def doc_desc(dic:dict = { "Person=1": "第一人称",
+  "Person=3": "第三人称",
+  "Person=2": "第二人称",
+  "Number=Sing": "单数",
+  "Gender=Fem": "阴性",
+  "Gender=Masc": "阳性",
+  "auxpass":"被动",
+  "AUX": "助动词",
+  "VERB": "动词",
+  "NOUN": "名词",
+  "ADJ": "形容词",
+  "JJR": "比较级",
+  "JJS": "最高级", 
+  "ADV": "副词",
+  "RBR": "比较级",
+  "RBS": "最高级", 
+  "PRON": "代词",
+  "dobj": "宾语",
+  "nsubj": "主语",
+  "ROOT": "谓语",
+  "acomp": "表语",
+  "Tense=Pres": "现在时",
+  "Tense=Past": "过去时"}
 			, text:str='She is happy.', debug:bool=True): 
 	''' 句子成分描述, 2022.7.10 '''
 	doc		= spacy.nlp(text) #t.morph.to_json():  'Case=Nom|Number=Sing|Person=1|PronType=Prs'
 	predi	= [ t.i for t in doc if t.dep_ == 'ROOT'][0]
 	lat = { t.i: [ f"单词<span class='{t.pos_} {t.tag_}'>{t.text}</span>是 {dic[t.pos_]}"] if t.pos_ in dic else []  for t in doc  } 
-	[ lat[t.i].append( dic[t.dep_] if t.dep_ == 'ROOT' else f"单词<span class='{t.head.pos_} {t.head.tag_}'>{t.head.text}</span>的{dic[t.dep_]}" )  for t in doc if t.dep_ in dic and t.head.i == predi ] # only show the first level, the direct child of pred 
+	[ lat[t.i].append( dic[t.dep_] if t.dep_  in ('ROOT','auxpass') else f"单词<span class='{t.head.pos_} {t.head.tag_}'>{t.head.text}</span>的{dic[t.dep_]}" )  for t in doc if t.dep_ in dic and t.head.i == predi ] # only show the first level, the direct child of pred 
+	[ lat[t.i].append( dic[t.tag_]) for t in doc if t.tag_ in dic ] # JJR
 	[ lat[t.i].append( dic[pair])  for t in doc for pair in t.morph if pair in dic ] # Person=1
 	res =  {"result": ["，".join(v) for v in lat.values() if v]}
 	if debug: res['tok'] = { t.i: (t.text, t.pos_, t.tag_, t.dep_, t.head.i, t.morph.to_json()) for t in doc}
